aboutsummaryrefslogtreecommitdiffstats
path: root/coin_test_instructions.py
diff options
context:
space:
mode:
authorSimo Fält <simo.falt@qt.io>2023-01-19 15:06:46 +0200
committerSimo Fält <simo.falt@qt.io>2023-02-22 13:14:26 +0200
commit4c42779f7fda9290076c1818379e4fbc78d308ab (patch)
tree37da1392f4f961084332f0f2d7c9060e453fbc86 /coin_test_instructions.py
parent9a5a0310d73fddf88848ed73949237af255d828f (diff)
CI: Change the way we create wheels in CI
Instead of calling setup.py to re-use binaries and creating wheels we can call create_wheels.py directly from CI instructions. This enables us to sign Windows binaries in correct phase and directory. Pick-to: 6.4 Change-Id: I7c69abe6e0b6591fb1df1e2f2805a015a49ce944 Reviewed-by: Cristian Maureira-Fredes <cristian.maureira-fredes@qt.io>
Diffstat (limited to 'coin_test_instructions.py')
-rw-r--r--coin_test_instructions.py16
1 files changed, 9 insertions, 7 deletions
diff --git a/coin_test_instructions.py b/coin_test_instructions.py
index 54b9127a9..d89e47374 100644
--- a/coin_test_instructions.py
+++ b/coin_test_instructions.py
@@ -72,13 +72,15 @@ def call_testrunner(python_ver, buildnro):
# Try to install built wheels, and build some buildable examples.
if CI_RELEASE_CONF:
wheel_tester_path = os.path.join("testing", "wheel_tester.py")
- # Run the test for the old set of wheels
- cmd = [env_python, wheel_tester_path, qmake_path]
- run_instruction(cmd, "Error while running wheel_tester.py on old wheels")
-
- # Uninstalling the other wheels
- run_instruction([env_pip, "uninstall", "shiboken6", "shiboken6_generator", "pyside6", "-y"],
- "Failed to uninstall old wheels")
+ # We create wheels differently in Qt CI with Windows and there are no "old" wheels
+ if CI_HOST_OS != "Windows":
+ # Run the test for the old set of wheels
+ cmd = [env_python, wheel_tester_path, qmake_path]
+ run_instruction(cmd, "Error while running wheel_tester.py on old wheels")
+
+ # Uninstalling the other wheels
+ run_instruction([env_pip, "uninstall", "shiboken6", "shiboken6_generator", "pyside6", "-y"],
+ "Failed to uninstall old wheels")
# Run the test for the new set of wheels
cmd = [env_python, wheel_tester_path, qmake_path, "--wheels-dir=dist_new", "--new"]